@@ -10,7 +10,7 @@ use warnings;
 use Data::Unixish::_pad;
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.43'; # VERSION
+our $VERSION = '1.44'; # VERSION
 
 our %SPEC;
 
@@ -31,6 +31,7 @@ _
         width => {
             schema => ['int*', min => 0],
             req => 1,
+            pos => 0,
             cmdline_aliases => { w => {} },
         },
         ansi => {
@@ -81,7 +82,11 @@ Data::Unixish::centerpad - Center text to a certain column width
 
 =head1 VERSION
 
-version 1.43
+version 1.44
+
+=head1 RELEASE DATE
+
+2014-04-24
 
 =head1 SYNOPSIS
 
