@@ -9,7 +9,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.43'; # VERSION
+our $VERSION = '1.44'; # VERSION
 
 our %SPEC;
 
@@ -49,8 +49,12 @@ sub _map_begin {
     my $args = shift;
 
     if (ref($args->{callback}) ne 'CODE') {
-        $args->{callback} = eval "sub { $args->{callback} }";
-        die "invalid Perl code for map: $@" if $@;
+        if ($args->{-cmdline}) {
+            $args->{callback} = eval "sub { $args->{callback} }";
+            die "invalid Perl code for map: $@" if $@;
+        } else {
+            die "Please supply coderef for 'callback'";
+        }
     }
 }
 
@@ -75,7 +79,11 @@ Data::Unixish::map - Perl map
 
 =head1 VERSION
 
-version 1.43
+version 1.44
+
+=head1 RELEASE DATE
+
+2014-04-24
 
 =head1 SYNOPSIS
 
