@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.43'; # VERSION
+our $VERSION = '1.44'; # VERSION
 
 our %SPEC;
 
@@ -22,6 +22,7 @@ $SPEC{pick} = {
             schema=>['int*' => {default=>1}],
             tags => ['main'],
             cmdline_aliases => { n=>{} },
+            pos => 0,
         },
     },
     tags => [qw/filtering/],
@@ -63,7 +64,11 @@ Data::Unixish::pick - Pick one or more random items
 
 =head1 VERSION
 
-version 1.43
+version 1.44
+
+=head1 RELEASE DATE
+
+2014-04-24
 
 =head1 SYNOPSIS
 
